@@ -39,7 +39,6 @@
 #include <gdk/gdkx.h>
 #include <gio/gio.h>
 #include <glib/gi18n.h>
-#include <gtk/gtk.h>
 #include <stdlib.h>
 
 #include "config.h"
@@ -81,6 +80,11 @@ static int gcrypt_thread_initialized = 0;
 #endif  /* HAVE_LIBGCRYPT */
 
 gboolean kioskmode;
+gboolean disablenews;
+gboolean disabletoolbar;
+gboolean fullscreen;
+gboolean extrahardening;
+gboolean disabletrayicon;
 
 static GOptionEntry remmina_options[] =
 {
@@ -121,6 +125,11 @@ static GOptionEntry remmina_options[] =
 	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
 	{ "set-option",	      0,    0,			  G_OPTION_ARG_STRING_ARRAY,   NULL, N_("Set one or more profile settings, to be used with --update-profile"),		     NULL	},
 	{ "encrypt-password", 0,    0,			  G_OPTION_ARG_NONE,	       NULL, N_("Encrypt a password"),												  NULL		 },
+	{ "disable-news", 0,    0,			  G_OPTION_ARG_NONE,	       NULL, N_("Disable news notification"),												  NULL		 },
+	{ "disable-toolbar", 0,    0,			  G_OPTION_ARG_NONE,	       NULL, N_("Disable toolbar"),												  NULL		 },
+	{ "enable-fullscreen", 0,    0,			  G_OPTION_ARG_NONE,	       NULL, N_("Enable fullscreen"),												  NULL		 },
+	{ "enable-extra-hardening", 0,    0,		  G_OPTION_ARG_NONE,	       NULL, N_("Enable extra hardening (disable closing confirmation, disable unsafe shortcut keys, hide tabs, hide search bar)"),	  NULL		 },
+	{ "no-tray-icon", 0,    0,			  G_OPTION_ARG_NONE,	       NULL, N_("Disable tray icon"),												  NULL		 },
 	{ NULL }
 };
 
@@ -152,10 +161,30 @@ static gint remmina_on_command_line(GApplication *app, GApplicationCommandLine *
 #if SODIUM_VERSION_INT >= 90200
 	remmina_sodium_init();
 #endif
-	remmina_pref_init();
-
 	opts = g_application_command_line_get_options_dict(cmdline);
 
+	if (g_variant_dict_lookup_value(opts, "disable-news", NULL)) {
+		disablenews = TRUE;
+	}
+
+	if (g_variant_dict_lookup_value(opts, "disable-toolbar", NULL)) {
+		disabletoolbar = TRUE;
+	}
+
+	if (g_variant_dict_lookup_value(opts, "enable-fullscreen", NULL)) {
+		fullscreen = TRUE;
+	}
+
+	if (g_variant_dict_lookup_value(opts, "enable-extra-hardening", NULL)) {
+		extrahardening = TRUE;
+	}
+
+	if (g_variant_dict_lookup_value(opts, "no-tray-icon", NULL)) {
+		disabletrayicon = TRUE;
+	}
+
+	remmina_pref_init();
+
 	if (g_variant_dict_lookup_value(opts, "quit", NULL)) {
 		remmina_exec_command(REMMINA_COMMAND_EXIT, NULL);
 		executed = TRUE;
@@ -273,7 +302,7 @@ static void remmina_on_startup(GApplication *app)
 	if (!secret_plugin)
 		g_print("Warning: Remmina is running without a secret plugin. Passwords will be saved in a less secure way.\n");
 	else
-		if (!secret_plugin->is_service_available())
+		if (!secret_plugin->is_service_available(secret_plugin))
 			g_print("Warning: Remmina is running with a secrecy plugin, but it cannot connect to a secrecy service.\n");
 
 	remmina_exec_command(REMMINA_COMMAND_AUTOSTART, NULL);
