@@ -2,7 +2,7 @@
  * Remmina - The GTK+ Remote Desktop Client
  * Copyright (C) 2010 Vic Lee
  * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
- * Copyright (C) 2016-2021 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2016-2022 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,37 +35,38 @@
  */
 
 #include "config.h"
-#include <gtk/gtk.h>
+
 #include <glib/gi18n.h>
+
+#include "remmina_icon.h"
+
+#ifdef HAVE_LIBAPPINDICATOR
+#  ifdef HAVE_AYATANA_LIBAPPINDICATOR
+#    include <libayatana-appindicator/app-indicator.h>
+#  else
+#    include <libappindicator/app-indicator.h>
+#  endif
 #include "remmina_widget_pool.h"
 #include "remmina_pref.h"
 #include "remmina_exec.h"
+#ifdef HAVE_LIBAVAHI_CLIENT
 #include "remmina_avahi.h"
+#endif
 #include "remmina_applet_menu_item.h"
 #include "remmina_applet_menu.h"
 #include "rcw.h"
-#include "remmina_icon.h"
+#include "remmina_log.h"
 #include "remmina/remmina_trace_calls.h"
 #include "remmina_sysinfo.h"
 
-#ifdef HAVE_LIBAPPINDICATOR
-#ifdef HAVE_AYATANA_LIBAPPINDICATOR
-#include <libayatana-appindicator/app-indicator.h>
-#else
-#include <libappindicator/app-indicator.h>
-#endif
-#endif
-
 typedef struct _RemminaIcon {
-#ifdef HAVE_LIBAPPINDICATOR
 	AppIndicator *	icon;
-#else
-	GtkStatusIcon * icon;
-#endif
+	gboolean	indicator_connected;
+#ifdef HAVE_LIBAVAHI_CLIENT
 	RemminaAvahi *	avahi;
+#endif
 	guint32		popup_time;
 	gchar *		autostart_file;
-	gchar *		gsversion; // GnomeShell version string, or null if not available
 } RemminaIcon;
 
 static RemminaIcon remmina_icon =
@@ -75,25 +76,19 @@ void remmina_icon_destroy(void)
 {
 	TRACE_CALL(__func__);
 	if (remmina_icon.icon) {
-#ifdef HAVE_LIBAPPINDICATOR
 		app_indicator_set_status(remmina_icon.icon, APP_INDICATOR_STATUS_PASSIVE);
-#else
-		gtk_status_icon_set_visible(remmina_icon.icon, FALSE);
-#endif
 		remmina_icon.icon = NULL;
 	}
+#ifdef HAVE_LIBAVAHI_CLIENT
 	if (remmina_icon.avahi) {
 		remmina_avahi_free(remmina_icon.avahi);
 		remmina_icon.avahi = NULL;
 	}
+#endif
 	if (remmina_icon.autostart_file) {
 		g_free(remmina_icon.autostart_file);
 		remmina_icon.autostart_file = NULL;
 	}
-	if (remmina_icon.gsversion) {
-		g_free(remmina_icon.gsversion);
-		remmina_icon.gsversion = NULL;
-	}
 }
 
 static void remmina_icon_main(void)
@@ -114,6 +109,7 @@ static void remmina_icon_about(void)
 	remmina_exec_command(REMMINA_COMMAND_ABOUT, NULL);
 }
 
+#ifdef HAVE_LIBAVAHI_CLIENT
 static void remmina_icon_enable_avahi(GtkCheckMenuItem *checkmenuitem, gpointer data)
 {
 	TRACE_CALL(__func__);
@@ -130,6 +126,7 @@ static void remmina_icon_enable_avahi(GtkCheckMenuItem *checkmenuitem, gpointer
 	}
 	remmina_pref_save();
 }
+#endif
 
 static void remmina_icon_populate_additional_menu_item(GtkWidget *menu)
 {
@@ -219,11 +216,12 @@ static void remmina_icon_populate_extra_menu_item(GtkWidget *menu)
 	TRACE_CALL(__func__);
 	GtkWidget *menuitem;
 	gboolean new_ontop;
-	GHashTableIter iter;
-	gchar *tmp;
 
 	new_ontop = remmina_pref.applet_new_ontop;
 
+#ifdef HAVE_LIBAVAHI_CLIENT
+	GHashTableIter iter;
+	gchar *tmp;
 	/* Iterate all discovered services from Avahi */
 	if (remmina_icon.avahi) {
 		g_hash_table_iter_init(&iter, remmina_icon.avahi->discovered_services);
@@ -233,14 +231,7 @@ static void remmina_icon_populate_extra_menu_item(GtkWidget *menu)
 			remmina_applet_menu_add_item(REMMINA_APPLET_MENU(menu), REMMINA_APPLET_MENU_ITEM(menuitem));
 		}
 	}
-
-	/* Separator */
-	//menuitem = gtk_separator_menu_item_new();
-	//gtk_widget_show(menuitem);
-	//if (new_ontop)
-		//gtk_menu_shell_prepend(GTK_MENU_SHELL(menu), menuitem);
-	//else
-		//gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
+#endif
 
 	/* New Connection */
 	menuitem = remmina_applet_menu_item_new(REMMINA_APPLET_MENU_ITEM_NEW);
@@ -255,8 +246,6 @@ static void remmina_icon_populate_extra_menu_item(GtkWidget *menu)
 	g_signal_connect(G_OBJECT(menu), "edit-item", G_CALLBACK(remmina_icon_on_edit_item), NULL);
 }
 
-#ifdef HAVE_LIBAPPINDICATOR
-
 void
 remmina_icon_populate_menu(void)
 {
@@ -280,55 +269,6 @@ remmina_icon_populate_menu(void)
 	}
 }
 
-#else
-
-void remmina_icon_populate_menu(void)
-{
-	TRACE_CALL(__func__);
-}
-
-static void remmina_icon_popdown_menu(GtkWidget *widget, gpointer data)
-{
-	TRACE_CALL(__func__);
-	if (gtk_get_current_event_time() - remmina_icon.popup_time <= 500)
-		remmina_exec_command(REMMINA_COMMAND_MAIN, NULL);
-}
-
-static void remmina_icon_on_activate(GtkStatusIcon *icon, gpointer user_data)
-{
-	TRACE_CALL(__func__);
-	GtkWidget *menu;
-	gint button, event_time;
-
-	remmina_icon.popup_time = gtk_get_current_event_time();
-	menu = remmina_applet_menu_new();
-	remmina_applet_menu_set_hide_count(REMMINA_APPLET_MENU(menu), remmina_pref.applet_hide_count);
-	remmina_applet_menu_populate(REMMINA_APPLET_MENU(menu));
-
-	remmina_icon_populate_extra_menu_item(menu);
-
-	button = 0;
-	event_time = gtk_get_current_event_time();
-
-	g_signal_connect(G_OBJECT(menu), "deactivate", G_CALLBACK(remmina_icon_popdown_menu), NULL);
-
-	gtk_menu_popup(GTK_MENU(menu), NULL, NULL, gtk_status_icon_position_menu, remmina_icon.icon, button, event_time);
-}
-
-static void remmina_icon_on_popup_menu(GtkStatusIcon *icon, guint button, guint activate_time, gpointer user_data)
-{
-	TRACE_CALL(__func__);
-	GtkWidget *menu;
-
-	menu = gtk_menu_new();
-
-	remmina_icon_populate_additional_menu_item(menu);
-
-	gtk_menu_popup(GTK_MENU(menu), NULL, NULL, gtk_status_icon_position_menu, remmina_icon.icon, button, activate_time);
-}
-
-#endif
-
 static void remmina_icon_save_autostart_file(GKeyFile *gkeyfile)
 {
 	TRACE_CALL(__func__);
@@ -343,11 +283,11 @@ static void remmina_icon_save_autostart_file(GKeyFile *gkeyfile)
 static void remmina_icon_create_autostart_file(void)
 {
 	TRACE_CALL(__func__);
-	GKeyFile *gkeyfile;
-
 	if (g_file_test(remmina_icon.autostart_file, G_FILE_TEST_EXISTS))
 		return;
 
+	GKeyFile *gkeyfile;
+
 	gkeyfile = g_key_file_new();
 	g_key_file_set_string(gkeyfile, "Desktop Entry", "Version", "1.0");
 	// TRANSLATORS: Applet name as per the Freedesktop Desktop entry specification https://specifications.freedesktop.org/desktop-entry-spec/latest/
@@ -373,121 +313,90 @@ static void remmina_icon_create_autostart_file(void)
 gboolean remmina_icon_is_available(void)
 {
 	TRACE_CALL(__func__);
-	gchar *gsversion;
-	unsigned int gsv_maj, gsv_min, gsv_seq;
-	gboolean gshell_has_legacyTray;
 
 	if (!remmina_icon.icon)
 		return FALSE;
 	if (remmina_pref.disable_tray_icon)
 		return FALSE;
 
-	/* Special treatmen under GNOME Shell */
-	if ((gsversion = remmina_sysinfo_get_gnome_shell_version()) != NULL) {
-		if (sscanf(gsversion, "%u.%u", &gsv_maj, &gsv_min) == 2)
-			gsv_seq = gsv_maj << 16 | gsv_min << 8;
-		else
-			gsv_seq = 0x030000;
-		g_free(gsversion);
-
-		gshell_has_legacyTray = FALSE;
-		if (gsv_seq >= 0x031000 && gsv_seq <= 0x031800)
-			/* GNOME Shell from 3.16 to 3.24, Status Icon (GtkStatusIcon) is visible in the drawer
-			 * at the bottom left of the screen */
-			gshell_has_legacyTray = TRUE;
-
-
-#ifdef HAVE_LIBAPPINDICATOR
-		/** GNOME Shell with compiled in LIBAPPINDICATOR:
-		 * ensure have also a working appindicator extension available.
-		 */
-		if (remmina_sysinfo_is_appindicator_available())
-			/* No libappindicator extension for GNOME Shell, no remmina_icon */
-			return TRUE;
-		else if (gshell_has_legacyTray)
-			return TRUE;
-		else
-			return FALSE;
-
-#endif
-		/* GNOME Shell without LIBAPPINDICATOR */
-		if (gshell_has_legacyTray)
-			return TRUE;
-		else
-			/* GNOME Shell < 3.16, Status Icon (GtkStatusIcon) is hidden
-			 * in the message tray */
-			return FALSE;
+	if (remmina_icon.indicator_connected == FALSE) {
+		REMMINA_DEBUG("Indicator is not connected to panel, thus it cannot be displayed.");
+		return FALSE;
+	} else {
+		REMMINA_DEBUG("Indicator is connected to panel, thus it can be displayed.");
+		return TRUE;
 	}
+	/** Special treatment under GNOME Shell
+	 * Remmina > v1.4.18 won't be shipped in distributions with GNOME Shell <= 3.18
+	 * therefore checking the the GNOME Shell version is useless.
+	 * We just return TRUE
+	 */
 	return TRUE;
 }
 
+static void
+remmina_icon_connection_changed_cb(AppIndicator *indicator, gboolean connected, gpointer data)
+{
+	TRACE_CALL(__func__);
+	REMMINA_DEBUG("Indicator connection changed to: %d", connected);
+	remmina_icon.indicator_connected = connected;
+}
+
 void remmina_icon_init(void)
 {
 	TRACE_CALL(__func__);
 
-	gchar remmina_panel[23];
+	gchar remmina_panel[29];
 	gboolean sni_supported;
-	char msg[200];
-
-	if (remmina_pref.dark_tray_icon)
-		g_stpcpy(remmina_panel, "remmina-panel-inverted");
-	else
-		g_stpcpy(remmina_panel, "remmina-panel");
 
+	g_stpcpy(remmina_panel, "org.remmina.Remmina-status");
 
 	/* Print on stdout the availability of appindicators on DBUS */
 	sni_supported = remmina_sysinfo_is_appindicator_available();
 
-	strcpy(msg, "StatusNotifier/Appindicator support: ");
-	if (sni_supported) {
-		strcat(msg, "your desktop does support it");
-#ifdef HAVE_LIBAPPINDICATOR
-		strcat(msg, " and libappindicator is compiled in Remmina. Good.");
-#else
-		strcat(msg, ", but you did not compile Remmina with CMake’s -DWITH_APPINDICATOR=on");
-#endif
-	} else {
-#ifdef HAVE_LIBAPPINDICATOR
-		strcat(msg, "not supported by desktop. libappindicator will try to fallback to GtkStatusIcon/xembed");
-#else
-		strcat(msg, "not supported by desktop. Remmina will try to fallback to GtkStatusIcon/xembed");
-#endif
-	}
-	strcat(msg, "\n");
-	fputs(msg, stderr);
+	g_autofree gchar *wmname = g_ascii_strdown(remmina_sysinfo_get_wm_name(), -1);
+	//TRANSLATORS: These are Linux desktop components to show icons in the system tray, after the “ there's the Desktop Name (like GNOME).
+	g_autofree gchar *msg = g_strconcat(
+		_("StatusNotifier/Appindicator support in “"),
+		wmname,
+		"”:",
+		NULL);
 
-	remmina_icon.gsversion = remmina_sysinfo_get_gnome_shell_version();
-	if (remmina_icon.gsversion != NULL)
-		printf("Running under GNOME Shell version %s\n", remmina_icon.gsversion);
+	if (sni_supported) {
+		//TRANSLATORS: %s is a placeholder for "StatusNotifier/Appindicator suppor in “DESKTOP NAME”: "
+		REMMINA_INFO(_("%s your desktop does support it"), msg);
+		//TRANSLATORS: %s is a placeholder for "StatusNotifier/Appindicator suppor in “DESKTOP NAME”: "
+		REMMINA_INFO(_("%s and Remmina has built-in (compiled) support for libappindicator."), msg);
+	} else {
+		//TRANSLATORS: %s is a placeholder for "StatusNotifier/Appindicator suppor in “DESKTOP NAME”: "
+		REMMINA_INFO(_("%s not supported natively by your Desktop Environment. libappindicator will try to fallback to GtkStatusIcon/xembed"), msg);
+	}
+	if (g_strrstr(wmname, "mate") != NULL)
+		//TRANSLATORS: %s is a placeholder for "StatusNotifier/Appindicator suppor in “DESKTOP NAME”: "
+		REMMINA_INFO(_("%s You may need to install, and use XApp Status Applet"), msg);
+	if (g_strrstr(wmname, "kde") != NULL)
+		//TRANSLATORS: %s is a placeholder for "StatusNotifier/Appindicator suppor in “DESKTOP NAME”: "
+		REMMINA_INFO(_("%s You may need to install, and use KStatusNotifierItem"), msg);
+	if (g_strrstr(wmname, "plasma") != NULL)
+		//TRANSLATORS: %s is a placeholder for "StatusNotifier/Appindicator suppor in “DESKTOP NAME”: "
+		REMMINA_INFO(_("%s You may need to install, and use XEmbed SNI Proxy"), msg);
+	if (g_strrstr(wmname, "gnome") != NULL)
+		//TRANSLATORS: %s is a placeholder for "StatusNotifier/Appindicator suppor in “DESKTOP NAME”: "
+		REMMINA_INFO(_("%s You may need to install, and use Gnome Shell Extension Appindicator"), msg);
 
 	if (!remmina_icon.icon && !remmina_pref.disable_tray_icon) {
-#ifdef HAVE_LIBAPPINDICATOR
 		remmina_icon.icon = app_indicator_new("remmina-icon", remmina_panel, APP_INDICATOR_CATEGORY_APPLICATION_STATUS);
-		app_indicator_set_icon_theme_path(remmina_icon.icon, REMMINA_RUNTIME_DATADIR G_DIR_SEPARATOR_S "icons");
-
 		app_indicator_set_status(remmina_icon.icon, APP_INDICATOR_STATUS_ACTIVE);
 		app_indicator_set_title(remmina_icon.icon, "Remmina");
 		remmina_icon_populate_menu();
-#else
-		remmina_icon.icon = gtk_status_icon_new_from_icon_name(remmina_panel);
-
-		gtk_status_icon_set_title(remmina_icon.icon, _("Remmina Remote Desktop Client"));
-		gtk_status_icon_set_tooltip_text(remmina_icon.icon, _("Remmina Remote Desktop Client"));
-
-		g_signal_connect(G_OBJECT(remmina_icon.icon), "popup-menu", G_CALLBACK(remmina_icon_on_popup_menu), NULL);
-		g_signal_connect(G_OBJECT(remmina_icon.icon), "activate", G_CALLBACK(remmina_icon_on_activate), NULL);
-#endif
 	} else if (remmina_icon.icon) {
-#ifdef HAVE_LIBAPPINDICATOR
 		app_indicator_set_status(remmina_icon.icon, remmina_pref.disable_tray_icon ?
 					 APP_INDICATOR_STATUS_PASSIVE : APP_INDICATOR_STATUS_ACTIVE);
 		/* With libappindicator we can also change the icon on the fly */
 		app_indicator_set_icon(remmina_icon.icon, remmina_panel);
-#else
-		gtk_status_icon_set_visible(remmina_icon.icon, !remmina_pref.disable_tray_icon);
-
-#endif
 	}
+	remmina_icon.indicator_connected = TRUE;
+#ifdef HAVE_LIBAVAHI_CLIENT
 	if (!remmina_icon.avahi)
 		remmina_icon.avahi = remmina_avahi_new();
 	if (remmina_icon.avahi) {
@@ -498,10 +407,14 @@ void remmina_icon_init(void)
 			remmina_avahi_stop(remmina_icon.avahi);
 		}
 	}
-	if (!remmina_icon.autostart_file) {
+#endif
+	if (!remmina_icon.autostart_file && !remmina_pref.disable_tray_icon) {
 		remmina_icon.autostart_file = g_strdup_printf("%s/.config/autostart/remmina-applet.desktop", g_get_home_dir());
 		remmina_icon_create_autostart_file();
 	}
+	// "connected" property means a visible indicator, otherwise could be hidden. or fall back to GtkStatusIcon
+	g_signal_connect(G_OBJECT(remmina_icon.icon), "connection-changed", G_CALLBACK(remmina_icon_connection_changed_cb), NULL);
+	//g_object_get(G_OBJECT(remmina_icon.icon), "connected", &remmina_icon.indicator_connected, NULL);
 }
 
 gboolean remmina_icon_is_autostart(void)
@@ -537,3 +450,12 @@ void remmina_icon_set_autostart(gboolean autostart)
 	}
 	g_key_file_free(gkeyfile);
 }
+
+#else
+void remmina_icon_init(void) {};
+void remmina_icon_destroy(void) {};
+gboolean remmina_icon_is_available(void) {return FALSE;};
+void remmina_icon_populate_menu(void) {};
+void remmina_icon_set_autostart(gboolean autostart) {} ;
+gboolean remmina_icon_is_autostart(void) {return FALSE;};
+#endif
