@@ -60,6 +60,9 @@ static gboolean remmina_masterthread_exec_callback(RemminaMTExecData *d)
 		case FUNC_FILE_GET_STRING:
 			d->p.file_get_string.retval = remmina_file_get_string( d->p.file_get_string.remminafile, d->p.file_get_string.setting );
 			break;
+		case FUNC_FILE_SET_STRING:
+			remmina_file_set_string( d->p.file_set_string.remminafile, d->p.file_set_string.setting, d->p.file_set_string.value );
+			break;
 		case FUNC_GTK_LABEL_SET_TEXT:
 			gtk_label_set_text( d->p.gtk_label_set_text.label, d->p.gtk_label_set_text.str );
 			break;
