@@ -288,6 +288,9 @@ void remmina_pref_init(void)
 	else
 		remmina_pref.confirm_close = TRUE;
 
+	if (extrahardening)
+		remmina_pref.confirm_close = FALSE;
+
 	if (g_key_file_has_key(gkeyfile, "remmina_pref", "use_master_password", NULL)) {
 		remmina_pref.use_primary_password = g_key_file_get_boolean(gkeyfile, "remmina_pref", "use_master_password", NULL);
 	} else if (g_key_file_has_key(gkeyfile, "remmina_pref", "use_primary_password", NULL))
@@ -360,18 +363,27 @@ void remmina_pref_init(void)
 	else
 		remmina_pref.always_show_tab = TRUE;
 
+	if (extrahardening)
+		remmina_pref.always_show_tab = FALSE;
+
 	if (g_key_file_has_key(gkeyfile, "remmina_pref", "hide_connection_toolbar", NULL))
 		remmina_pref.hide_connection_toolbar = g_key_file_get_boolean(gkeyfile, "remmina_pref",
 									      "hide_connection_toolbar", NULL);
 	else
 		remmina_pref.hide_connection_toolbar = FALSE;
 
+	if (disabletoolbar)
+		remmina_pref.hide_connection_toolbar = TRUE;
+
 	if (g_key_file_has_key(gkeyfile, "remmina_pref", "hide_searchbar", NULL))
 		remmina_pref.hide_searchbar = g_key_file_get_boolean(gkeyfile, "remmina_pref",
 								     "hide_searchbar", NULL);
 	else
 		remmina_pref.hide_searchbar = FALSE;
 
+	if (extrahardening)
+		remmina_pref.hide_searchbar = TRUE;
+
 	if (g_key_file_has_key(gkeyfile, "remmina_pref", "default_action", NULL))
 		remmina_pref.default_action = g_key_file_get_integer(gkeyfile, "remmina_pref", "default_action", NULL);
 	else
@@ -527,6 +539,9 @@ void remmina_pref_init(void)
 	else
 		remmina_pref.disable_tray_icon = FALSE;
 
+	if (disabletrayicon)
+		remmina_pref.disable_tray_icon = TRUE;
+
 	if (g_key_file_has_key(gkeyfile, "remmina_pref", "dark_theme", NULL))
 		remmina_pref.dark_theme = g_key_file_get_boolean(gkeyfile, "remmina_pref", "dark_theme", NULL);
 	else
@@ -557,6 +572,9 @@ void remmina_pref_init(void)
 	else
 		remmina_pref.default_mode = 0;
 
+	if (fullscreen)
+		remmina_pref.default_mode = VIEWPORT_FULLSCREEN_MODE;
+
 	if (g_key_file_has_key(gkeyfile, "remmina_pref", "tab_mode", NULL))
 		remmina_pref.tab_mode = g_key_file_get_integer(gkeyfile, "remmina_pref", "tab_mode", NULL);
 	else
@@ -567,6 +585,9 @@ void remmina_pref_init(void)
 	else
 		remmina_pref.fullscreen_toolbar_visibility = FLOATING_TOOLBAR_VISIBILITY_PEEKING;
 
+	if (disabletoolbar)
+		remmina_pref.fullscreen_toolbar_visibility = FLOATING_TOOLBAR_VISIBILITY_DISABLE;
+
 	if (g_key_file_has_key(gkeyfile, "remmina_pref", "auto_scroll_step", NULL))
 		remmina_pref.auto_scroll_step = g_key_file_get_integer(gkeyfile, "remmina_pref", "auto_scroll_step", NULL);
 	else
