@@ -42,8 +42,6 @@
 #include <gmodule.h>
 #include <stdlib.h>
 
-
-
 #include "remmina_chat_window.h"
 #include "remmina_masterthread_exec.h"
 #include "remmina_ext_exec.h"
@@ -282,15 +280,21 @@ void remmina_protocol_widget_open_connection_real(gpointer data)
 			feature->type = REMMINA_PROTOCOL_FEATURE_TYPE_TOOL;
 			feature->id = REMMINA_PROTOCOL_FEATURE_TOOL_SSH;
 			feature->opt1 = _("Connect via SSH from a new terminal");
+			feature->opt1_type_hint = REMMINA_TYPEHINT_STRING;
 			feature->opt2 = "utilities-terminal";
+			feature->opt2_type_hint = REMMINA_TYPEHINT_STRING;
 			feature->opt3 = NULL;
+			feature->opt3_type_hint = REMMINA_TYPEHINT_UNDEFINED;
 			feature++;
 
 			feature->type = REMMINA_PROTOCOL_FEATURE_TYPE_TOOL;
 			feature->id = REMMINA_PROTOCOL_FEATURE_TOOL_SFTP;
 			feature->opt1 = _("Open SFTP transfer…");
+			feature->opt1_type_hint = REMMINA_TYPEHINT_STRING;
 			feature->opt2 = "folder-remote";
+			feature->opt2_type_hint = REMMINA_TYPEHINT_STRING;
 			feature->opt3 = NULL;
+			feature->opt3_type_hint = REMMINA_TYPEHINT_UNDEFINED;
 			feature++;
 		}
 		feature->type = REMMINA_PROTOCOL_FEATURE_TYPE_END;
@@ -593,7 +597,7 @@ void remmina_protocol_widget_send_clip_strokes(GtkClipboard *clipboard, const gc
 {
 	TRACE_CALL(__func__);
 	RemminaProtocolWidget *gp = REMMINA_PROTOCOL_WIDGET(data);
-	gchar *text = g_strdup(clip_text);
+	gchar *text = g_utf8_normalize(clip_text, -1, G_NORMALIZE_DEFAULT_COMPOSE);
 	guint *keyvals;
 	gint i;
 	GdkKeymap *keymap = gdk_keymap_get_for_display(gdk_display_get_default());
@@ -630,18 +634,22 @@ void remmina_protocol_widget_send_clip_strokes(GtkClipboard *clipboard, const gc
 				REMMINA_DEBUG("Text clipboard after replacement is \'%s\'", text);
 			}
 			gchar *iter = g_strdup(text);
+			REMMINA_DEBUG("Iter: %s", iter),
 			keyvals = (guint *)g_malloc(strlen(text));
 			while (TRUE) {
 				/* Process each character in the keystrokes */
 				character = g_utf8_get_char_validated(iter, -1);
+				REMMINA_DEBUG("Char: U+%04" G_GINT32_FORMAT"X", character);
 				if (character == 0)
 					break;
 				keyval = gdk_unicode_to_keyval(character);
+				REMMINA_DEBUG("Keyval: %u", keyval);
 				/* Replace all the special character with its keyval */
 				for (i = 0; text_replaces[i].replace; i++) {
 					if (character == text_replaces[i].replace[0]) {
 						keys = g_new0(GdkKeymapKey, 1);
 						keyval = text_replaces[i].keyval;
+						REMMINA_DEBUG("Special Keyval: %u", keyval);
 						/* A special character was generated, no keyval lookup needed */
 						character = 0;
 						break;
@@ -651,7 +659,7 @@ void remmina_protocol_widget_send_clip_strokes(GtkClipboard *clipboard, const gc
 				if (character) {
 					/* get keyval without modifications */
 					if (!gdk_keymap_get_entries_for_keyval(keymap, keyval, &keys, &n_keys)) {
-						g_warning("keyval 0x%04x has no keycode!", keyval);
+						REMMINA_WARNING("keyval 0x%04x has no keycode!", keyval);
 						iter = g_utf8_find_next_char(iter, NULL);
 						continue;
 					}
@@ -1012,14 +1020,13 @@ static gboolean remmina_protocol_widget_tunnel_destroy(RemminaSSHTunnel *tunnel,
 {
 	TRACE_CALL(__func__);
 	RemminaProtocolWidget *gp = REMMINA_PROTOCOL_WIDGET(data);
-	guint idx;
-	gboolean found;
+	guint idx = 0;
 
 #if GLIB_CHECK_VERSION(2, 54, 0)
-	found = g_ptr_array_find(gp->priv->ssh_tunnels, tunnel, &idx);
+	gboolean found = g_ptr_array_find(gp->priv->ssh_tunnels, tunnel, &idx);
 #else
 	int i;
-	found = FALSE;
+	gboolean found = FALSE;
 	for (i = 0; i < gp->priv->ssh_tunnels->len; i++) {
 		if ((RemminaSSHTunnel *)gp->priv->ssh_tunnels->pdata[i] == tunnel) {
 			found = TRUE;
@@ -1051,7 +1058,7 @@ gchar *remmina_protocol_widget_start_direct_tunnel(RemminaProtocolWidget *gp, gi
 	const gchar *server;
 	const gchar *ssh_tunnel_server;
 	gchar *ssh_tunnel_host, *srv_host, *dest;
-	gint srv_port, ssh_tunnel_port;
+	gint srv_port, ssh_tunnel_port = 0;
 
 	REMMINA_DEBUG("SSH tunnel initialization…");
 
@@ -1366,6 +1373,11 @@ gint remmina_protocol_widget_get_profile_remote_height(RemminaProtocolWidget *gp
 	return gp->priv->profile_remote_height;
 }
 
+const gchar* remmina_protocol_widget_get_name(RemminaProtocolWidget *gp)
+{
+	TRACE_CALL(__func__);
+	return gp ? gp->plugin ? gp->plugin->name : NULL : NULL;
+}
 
 gint remmina_protocol_widget_get_width(RemminaProtocolWidget *gp)
 {
@@ -2102,6 +2114,7 @@ void remmina_protocol_widget_send_keys_signals(GtkWidget *widget, const guint *k
 			event.keyval = keyvals[i];
 			event.hardware_keycode = remmina_public_get_keycode_for_keyval(keymap, event.keyval);
 			event.is_modifier = (int)remmina_public_get_modifier_for_keycode(keymap, event.hardware_keycode);
+			REMMINA_DEBUG("Sending keyval: %u, hardware_keycode: %u", event.keyval, event.hardware_keycode);
 			g_signal_emit_by_name(G_OBJECT(widget), "key-press-event", &event, &result);
 		}
 	}
