@@ -40,7 +40,6 @@
 #include <gio/gio.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
-#include <gtk/gtk.h>
 #include <libsoup/soup.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -177,6 +176,8 @@ void rmnews_show_news(GtkWindow *parent)
 {
 	TRACE_CALL(__func__);
 
+	if (disablenews) return;
+
 	rmnews_news_dialog = g_new0(RemminaNewsDialog, 1);
 	rmnews_news_dialog->retval = 1;
 
