@@ -48,7 +48,10 @@ typedef struct _RemminaNewsDialog {
 
 #pragma once
 
+#include <gtk/gtk.h>
+
 G_BEGIN_DECLS
+extern gboolean disablenews;
 void rmnews_schedule();
 void rmnews_show_news();
 void rmnews_get_url(const char *url);
